##  PULL Webhooks
With PULL webhooks, a client requests events by polling an endpoint on the SAP LeanIX Webhooks API. To learn how to use PUSH webhooks, visit [PULL Webhooks](https://help.sap.com/docs/leanix/ea/pull-webhooks?locale=en-US&state=PRODUCTION&version=CLOUD "Request events by polling an API endpoint.").
YesNo
Send
